Contributing
============

The source code for GPAW is handled the same way as the source code for the
ASE project.  Read here about how to get started:
    
    https://wiki.fysik.dtu.dk/ase/development/contribute.html
